==> penguintv_3.0.orig.tar.gz: PenguinTV-3.0/share/penguintv.glade.h <==
char *s = N_(" ");
char *s = N_(" megabytes");
char *s = N_(" minutes");
char *s = N_("(c)2005 Owen Williams");
char *s = N_("0 bytes");
char *s = N_("<b>Add Feed</b>");
char *s = N_("<b>Add Search Tag</b>");
char *s = N_("<b>BitTorrent Options</b>");
char *s = N_("<b>Create Feed Filter</b>");
char *s = N_("<b>Feed Filter Properties</b>");
char *s = N_("<b>Feed Properties</b>");
char *s = N_("<b>General Options</b>");
char *s = N_("<b>Login Required</b>");
char *s = N_("<b>Modify Search Tag</b>");
char *s = N_("<b>Options</b>");
char *s = N_("<b>Refresh Mode</b>");
char *s = N_("<b>Synchronization Preview</b>");
char *s = N_("<b>Synchronizing Media</b>");
char *s = N_("<i>Copying...</i>");
char *s = N_("A username and password are required for this feed:");
char *s = N_("Add Feed");
char *s = N_("Add Search Tag");
char *s = N_("Add _Feed Filter...");
char *s = N_("All Feeds");
char *s = N_("Always show notification icon");
char *s = N_("Automatically download new media");
char *s = N_("Autotune refresh period");
char *s = N_("Browse...");
char *s = N_("Changing Layouts...");
char *s = N_("Clear Search");
char *s = N_("Copy _audio files only");
char *s = N_("Create Feed Filter");
char *s = N_("Description");
char *s = N_("Destination");
char *s = N_("Download Unviewed Media");
char *s = N_("Download _Unviewed Media");
char *s = N_("E_ntry");
char *s = N_("Edit Favorite Tags");
char *s = N_("Edit Saved Searches");
char *s = N_("Edit Tags");
char *s = N_("Fee_d");
char *s = N_("Feed Filter Properties");
char *s = N_("Feed Properties");
char *s = N_("Filtered Feed Name:");
char *s = N_("Homepage");
char *s = N_("Last Poll");
char *s = N_("Limit total disk usage to ");
char *s = N_("Login Required");
char *s = N_("Mark As _Unviewed");
char *s = N_("Mark As _Viewed");
char *s = N_("Maximum port");
char *s = N_("Minimum port");
char *s = N_("Modify");
char *s = N_("Modify Search Tag");
char *s = N_("Next Poll");
/* TRANSLATORS: Replace this string with your names, one name per line. */
char *s = N_("None yet");
char *s = N_("Original Feed Name: ");
char *s = N_("Password: ");
char *s = N_("Pause Selected Downloads");
char *s = N_("PenguinTV");
char *s = N_("PenguinTV Sourceforge Site");
char *s = N_("Play Unviewed Media");
char *s = N_("Please enter the URL of the feed you would like to add; and any tags you would like to apply to this feed, separated by commas:");
char *s = N_("Please enter the name for the new filtered feed, and the search terms you'd like to filter for");
char *s = N_("Please enter the search terms you'd like to save, and a name for this search.");
char *s = N_("Please wait while PenguinTV changes layouts...");
char *s = N_("Podcast and Video Blog aggregator for GTK+ and GNOME");
char *s = N_("Poll all feeds on startup");
char *s = N_("Preferences");
char *s = N_("RSS Feed");
char *s = N_("Re_fresh");
char *s = N_("Re_fresh Search Indexes");
char *s = N_("Refresh Feeds");
char *s = N_("Refresh Feeds with _Errors");
char *s = N_("Refresh every ");
char *s = N_("Remove Feed");
char *s = N_("Resume");
char *s = N_("Resume Selected Downloads");
char *s = N_("Resume _All");
char *s = N_("Resume downloads on startup");
char *s = N_("Save Search...");
char *s = N_("Search Feeds and Entries");
char *s = N_("Search Terms:");
char *s = N_("Select a destination where all the downloaded PenguinTV media will be copied.  If the destination is an mp3 player, make sure the mp3 player is connected before synchronizing.");
char *s = N_("Show All Tags");
char *s = N_("Stop Selected Downloads");
char *s = N_("Synchonization Preview");
char *s = N_("Synchronize");
char *s = N_("Synchronizing");
char *s = N_("Tag Editor...");
char *s = N_("Tag Highlighter:");
char *s = N_("Tag name: ");
char *s = N_("Tags:");
char *s = N_("Tags: ");
char *s = N_("Title");
char *s = N_("URL: ");
char *s = N_("Upload rate limit");
char *s = N_("User Name: ");
char *s = N_("Using: ");
char *s = N_("You can drag tags from the righthand side to the favorites list on the left.  To remove a favorite, drag it from the lefthand side back to the right.");
char *s = N_("You may change the name of this search as well as the search terms.");
char *s = N_("You may click on the items in the list to edit tags.");
char *s = N_("_Add Feed...");
char *s = N_("_Delete All Media");
char *s = N_("_Delete Media");
char *s = N_("_Delete files on destination that are no longer in the database");
char *s = N_("_Download Media");
char *s = N_("_Export Subscriptions...");
char *s = N_("_Fancy Feed Display");
char *s = N_("_Favorite Tags...");
char *s = N_("_Go");
char *s = N_("_Horizontal Layout");
char *s = N_("_Import Subscriptions...");
char *s = N_("_Mark As Viewed");
char *s = N_("_Planet Style Layout");
char *s = N_("_Play Media");
char *s = N_("_Play Unviewed");
char *s = N_("_Preview");
char *s = N_("_Properties");
char *s = N_("_Refresh Feeds");
char *s = N_("_Remove Feed");
char *s = N_("_Saved Searches...");
char *s = N_("_Show Today's Downloads...");
char *s = N_("_Standard Layout");
char *s = N_("_Synchronize");
char *s = N_("_Synchronize Media...");
char *s = N_("_Vertical Layout");
char *s = N_("_View");
char *s = N_("a");
char *s = N_("unknown");

==> penguintv_4.2.0.orig.tar.gz: PenguinTV-4.2.0/share/penguintv.glade.h <==
char *s = N_(" ");
char *s = N_(" megabytes");
char *s = N_(" minutes");
char *s = N_("(c)2007 Owen Williams");
char *s = N_("0 bytes");
char *s = N_("<b>Add Feed</b>");
char *s = N_("<b>Add Search Tag</b>");
char *s = N_("<b>BitTorrent Options</b>");
char *s = N_("<b>Create Feed Filter</b>");
char *s = N_("<b>Feed Filter Properties</b>");
char *s = N_("<b>General Options</b>");
char *s = N_("<b>Login Required</b>");
char *s = N_("<b>Modify Search Tag</b>");
char *s = N_("<b>Options</b>");
char *s = N_("<b>Refresh Mode</b>");
char *s = N_("<b>Synchronization Preview</b>");
char *s = N_("<b>Synchronizing Media</b>");
char *s = N_("<i>Copying...</i>");
char *s = N_("A username and password are required for this feed:");
char *s = N_("Add Feed");
char *s = N_("Add Search Tag");
char *s = N_("Add _Feed Filter...");
char *s = N_("All Feeds");
char *s = N_("Always show notification icon");
char *s = N_("Automatically download media");
char *s = N_("Automatically download new media");
char *s = N_("Autotune refresh period");
char *s = N_("Browse...");
char *s = N_("Clear Search");
char *s = N_("Convert newline characters to HTML paragraph breaks");
char *s = N_("Copy _audio files only");
char *s = N_("Create Feed Filter");
char *s = N_("Delete _files from the database after copying");
char *s = N_("Description");
char *s = N_("Destination");
char *s = N_("Download Unviewed Media");
char *s = N_("Download _Unviewed Media");
char *s = N_("E_ntry");
char *s = N_("Edit Favorite Tags");
char *s = N_("Edit Saved Searches");
char *s = N_("Edit Tags");
char *s = N_("Fee_d");
char *s = N_("Feed Filter Properties");
char *s = N_("Feed Properties");
char *s = N_("Filtered Feed Name:");
char *s = N_("Hide Viewed");
char *s = N_("Homepage");
char *s = N_("If unchecked, media may be deleted to free up space");
char *s = N_("Include this feed in search results");
char *s = N_("Last Poll");
char *s = N_("Limit total disk usage to ");
char *s = N_("Login Required");
char *s = N_("Mark As _Unviewed");
char *s = N_("Mark As _Viewed");
char *s = N_("Maximum port");
char *s = N_("Minimum port");
char *s = N_("Modify");
char *s = N_("Modify Search Tag");
char *s = N_("Never delete media automatically");
char *s = N_("Next Poll");
/* TRANSLATORS: Replace this string with your names, one name per line. */
char *s = N_("None yet");
char *s = N_("Options");
char *s = N_("Original Feed Name: ");
char *s = N_("Password: ");
char *s = N_("Pause Selected Downloads");
char *s = N_("PenguinTV");
char *s = N_("PenguinTV Sourceforge Site");
char *s = N_("Please enter the URL of the feed you would like to add; and any tags you would like to apply to this feed, separated by commas:");
char *s = N_("Please enter the name for the new filtered feed, and the search terms you'd like to filter for");
char *s = N_("Please enter the search terms you'd like to save, and a name for this search.");
char *s = N_("Podcast and Video Blog aggregator for GTK+ and GNOME");
char *s = N_("Poll all feeds on startup");
char *s = N_("Preferences");
char *s = N_("RSS Feed");
char *s = N_("Re_fresh");
char *s = N_("Re_fresh Search Indexes");
char *s = N_("Re_name");
char *s = N_("Refresh Feeds");
char *s = N_("Refresh Feeds with _Errors");
char *s = N_("Refresh every ");
char *s = N_("Remove Feed");
char *s = N_("Resume");
char *s = N_("Resume Selected Downloads");
char *s = N_("Resume _All");
char *s = N_("Resume downloads on startup");
char *s = N_("Save Search...");
char *s = N_("Search Feeds and Entries");
char *s = N_("Search Terms:");
char *s = N_("Select a destination where all the downloaded PenguinTV media will be copied.  If the destination is an mp3 player, make sure the mp3 player is connected before synchronizing.");
char *s = N_("Select a tag in the list on the left, and all the feeds with that tag will be marked on the right.  You may mark and unmark feeds to add or remove that tag from them.\n"
             "\n"
             "Tagged feeds will appear at the top of the list.");
char *s = N_("Show _Notifications");
char *s = N_("Show notifications when this feed updates");
char *s = N_("Stop Selected Downloads");
char *s = N_("Synchonization Preview");
char *s = N_("Synchronize");
char *s = N_("Synchronizing");
char *s = N_("TEMPORARY ICOPN");
char *s = N_("Tag Editor");
char *s = N_("Tag Editor...");
char *s = N_("Tag Highlighter:");
char *s = N_("Tag name: ");
char *s = N_("Tags:");
char *s = N_("Tags: ");
char *s = N_("Title");
char *s = N_("URL: ");
char *s = N_("Upload rate limit");
char *s = N_("User Name: ");
char *s = N_("Using: ");
char *s = N_("Work around feeds where entries appear to be in one large paragraph");
char *s = N_("You can drag tags from the righthand side to the favorites list on the left.  To remove a favorite, drag it from the lefthand side back to the right.");
char *s = N_("You may change the name of this search as well as the search terms.");
char *s = N_("You may click on the items in the list to edit tags.");
char *s = N_("_Add Feed...");
char *s = N_("_Delete All Media");
char *s = N_("_Delete Media");
char *s = N_("_Delete files on destination that are no longer in the database");
char *s = N_("_Download Media");
char *s = N_("_Export Subscriptions...");
char *s = N_("_Fancy Feed Display");
char *s = N_("_Favorite Tags...");
char *s = N_("_Go");
char *s = N_("_Horizontal Layout");
char *s = N_("_Import Subscriptions...");
char *s = N_("_Mark As Viewed");
char *s = N_("_Planet Style Layout");
char *s = N_("_Play Media");
char *s = N_("_Preview");
char *s = N_("_Properties");
char *s = N_("_Refresh Feeds");
char *s = N_("_Remove Feed");
char *s = N_("_Saved Searches...");
char *s = N_("_Show Today's Downloads...");
char *s = N_("_Standard Layout");
char *s = N_("_Synchronize");
char *s = N_("_Synchronize Media...");
char *s = N_("_Vertical Layout");
char *s = N_("_View");
char *s = N_("a");
char *s = N_("unknown");
